async fn scan_event_log(client: &Client, notes: &mut HashMap<Nonce, NoteRecord>)Expand description
Paginate through the entire event log, recording note timestamps.
async fn scan_event_log(client: &Client, notes: &mut HashMap<Nonce, NoteRecord>)Paginate through the entire event log, recording note timestamps.